==> risk-center-api-0.4.36-20190516.111443-3-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskIndustryWordDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
* 风控情报系统行业关键词库
*/
public class RiskIndustryWordDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 
    */
    private Long id;

    /**
    * 行业
    */
    private String industryName;

    /**
    * 敏感词
    */
    private String wordName;

    /**
    * 修改者
    */
    private String editor;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    private String oldIndustryName;

    private List<String> wordNameList;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setIndustryName(String industryName) {
        this.industryName = industryName;
    }

    public String getIndustryName() {
        return industryName;
    }

    public void setWordName(String wordName) {
        this.wordName = wordName;
    }

    public String getWordName() {
        return wordName;
    }

    public void setEditor(String editor) {
        this.editor = editor;
    }

    public String getEditor() {
        return editor;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public List<String> getWordNameList() {
        return wordNameList;
    }

    public void setWordNameList(List<String> wordNameList) {
        this.wordNameList = wordNameList;
    }

    public String getOldIndustryName() {
        return oldIndustryName;
    }

    public void setOldIndustryName(String oldIndustryName) {
        this.oldIndustryName = oldIndustryName;
    }
}

==> risk-center-api-0.5.5-20190718.022823-4-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/RiskIndustryWordDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
* 风控情报系统行业关键词库
*/
public class RiskIndustryWordDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 
    */
    private Long id;

    /**
    * 行业
    */
    private String industryName;

    /**
    * 敏感词
    */
    private String wordName;

    /**
    * 修改者
    */
    private String editor;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    private String newIndustryName;

    private String newWordName;

    private List<String> wordNameList;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setIndustryName(String industryName) {
        this.industryName = industryName;
    }

    public String getIndustryName() {
        return industryName;
    }

    public void setWordName(String wordName) {
        this.wordName = wordName;
    }

    public String getWordName() {
        return wordName;
    }

    public void setEditor(String editor) {
        this.editor = editor;
    }

    public String getEditor() {
        return editor;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public List<String> getWordNameList() {
        return wordNameList;
    }

    public void setWordNameList(List<String> wordNameList) {
        this.wordNameList = wordNameList;
    }

    public String getNewIndustryName() {
        return newIndustryName;
    }

    public void setNewIndustryName(String newIndustryName) {
        this.newIndustryName = newIndustryName;
    }

    public String getNewWordName() {
        return newWordName;
    }

    public void setNewWordName(String newWordName) {
        this.newWordName = newWordName;
    }
}
